package org.w3c.rdf.examples;

import org.xml.sax.SAXException;
import org.w3c.rdf.model.*;
import org.w3c.rdf.util.*;

/**
 * A simple demo program that parses RDF at a given URL,
 * serializes it back into RDF/XML, and dumps the triples.
 *
 * <p>Try <code>java org.w3c.rdf.examples.ParseAndSerialize http://www-db.stanford.edu/~melnik/</code>
 */

public class ParseAndSerialize {

  static void bailOut() {
      System.err.println("Usage: ParseAndSerialize [-triples | -xml] <fileNameOrURL>\n" + 
			 "If no option is specified both triples and XML is displayed.\n" +
			 "Use JVM option -Dorg.xml.sax.parser=<classname> to replace default XML parser.");
      System.exit(1);
  }

  public static void main(String[] args) throws Exception {

    boolean printTriples, printXML;
    String fileNameOrURL = null;

    printTriples = printXML = false;

    for(int i = 0; i < args.length; i++) {

      if(args[i].startsWith("-t"))
	printTriples = true;
      else if(args[i].startsWith("-x"))
	printXML = true;
      else
	fileNameOrURL = args[i];
    }

    if(fileNameOrURL == null)
      bailOut();

    if(!printTriples && !printXML)
      printTriples = printXML = true;

    RDFFactory f = new RDFFactoryImpl();
    Model m = f.createModel();
    
    try {
      RDFUtil.parse(fileNameOrURL, f.createParser(), m);
    } catch (SAXException se) {
      System.err.println("Exception during parsing: " + se.getMessage());
      throw se.getException();
    }

    if(printTriples) {
      System.err.println("\nTRIPLES:\n");
      RDFUtil.printStatements(m, System.out);
    }

    if(printXML) {
      System.err.println("\nSERIALIZED MODEL:\n");
      RDFUtil.dumpModel(m, System.out, f.createSerializer());
    }

    System.err.println("\nModel " + m.getURI() + " of size " + m.size() + "\n");
  }
}
