/**
 * Copyright  World Wide Web Consortium, (Massachusetts Institute of
 * Technology, Institut National de Recherche en Informatique et en
 * Automatique, Keio University).
 *
 * All Rights Reserved.
 *
 * @author	Sergey Melnik <melnik@db.stanford.edu>
 */
package org.w3c.rdf.implementation.model;

import org.w3c.rdf.model.*;
import org.w3c.rdf.util.*;
import org.w3c.rdf.digest.*;

public abstract class RDFNodeImpl implements RDFNode, Digestable {
  private boolean _alreadyComputedHashcode = false;
  private int _hashCode;

  protected Digest digest;

  public String	toString () {
    return getLabel();
  }

  public abstract String getLabel ();

  public int hashCode() {

    //    return getLabel().hashCode();

   if (false == _alreadyComputedHashcode)
   {
    try
    {
     _hashCode = DigestUtil.getHashCode(getDigest());
    }
    catch (DigestException exc)
    {
    _hashCode = super.hashCode();
    }
   }
   return _hashCode;
  }

  // implementation of Digestable

  public Digest getDigest() throws DigestException {

    if(digest == null) {
      try {
	digest = RDFDigestUtil.computeNodeDigest(this);
      } catch (ModelException exc) {
	throw new DigestException(exc.toString());
      }
    }
    return digest;
  }

  public boolean equals (Object that) {

    if(that instanceof Digestable) {
      try {
	return DigestUtil.equal(getDigest(), ((Digestable)that).getDigest());
      } catch (DigestException any) {}
    }

    try {
      return getLabel().equals( ((RDFNode)that).getLabel() );
    } catch (ModelException ex) {
      return false;
    }
  }
}
